/*
Copyright (C) 2002 Martin A. Olevitch
    Written by Martin A. Olevitch (marty@cosray.wustl.edu)

    This file is part of Shmed.

    Shmed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Shmed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Shmed, see the file COPYING; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * util.c - utility routines used in shmed
 *
 *	(should eventually become local library routines)
 *
 *	Marty Olevitch, March 1991
 */
 
#include <stdio.h>
#include <stdarg.h>
#include <strings.h>
#include <errno.h>

extern int errno;

/*
 - efopen - fopen() with error handling
 */
FILE *
efopen(filename, mode)
	char *filename;
	char *mode;
{
	FILE *fp;
	if((fp = fopen(filename, mode)) == NULL) {
		fprintf(stderr,"Can't open file '%s' mode '%s' (%s)\n",
			filename, mode, strerror(errno));
		exit(1);
	}
	return(fp);
}

/*
 - split - split a string into substrings
 *
 *	usage is split(str, sep, n, str1, str2, ...)
 *
 *		split string str on separator sep into the n substrings
 *		str1, str2, etc.
 *
 *		returns number of substrings extracted
 */
split(char *srcp, char *sep, int n, ...)
{
	va_list ap;
	int i;
	char *destp;/* destination strings */
	char *cp, *strtok();

	va_start(ap, n);

	for(i=0; i<n; i++) {
		destp = va_arg(ap, char *);
		if(i == 0)
			cp = strtok(srcp, sep);
		else
			cp = strtok(NULL, sep);
			
		if(cp != NULL) {
			strcpy(destp, cp);
		} else {
			strcpy(destp, "");		/* not enough fields */
			break;
		}
	}
	va_end(ap);
	return(i);
}
